@@ -1,9 +1,3 @@
-/*
- * Copyright (c) 2000, 2001    Paul Kinnucan
- *
- * $Revision: 1.2 $
- */
-
 package jde.debugger.command;
 import jde.debugger.JDEException;
 import jde.debugger.Etc;
@@ -18,6 +12,8 @@ import jde.debugger.Etc;
  * cancel_trace_threads <u>requestID</u>
  * </pre>
  *
+ * Copyright (c) 2000, 2001, 2003    Paul Kinnucan
+ * 
  * <b>Comments:</b>
  * <ul>
  * <li> <u>requestID</u> is returned in the trace threads reply
@@ -34,13 +30,12 @@ public class CancelTraceThreads extends DebugProcessCommand {
    * @exception jde.debugger.JDEException <description>
    */
   public void doCommand() throws JDEException {
-	if (args.size() < 1)
-	    throw new JDEException("Insufficient arguments");
+    if (m_args.size() < 1)
+      throw new JDEException("Insufficient arguments");
 
-	deleteIdentifiableRequest(Etc.safeGetLong
-				  (args.remove(0), "request ID"));
+    m_debugger.deleteIdentifiableRequest(Etc.safeGetLong(m_args.remove(0), "request ID"));
 
-	jde.signalCommandResult(procID, cmdID);
+    m_debugger.signalCommandResult(m_cmdID, null, CMD_OK);
   }
 
 
@@ -51,8 +46,8 @@ public class CancelTraceThreads extends DebugProcessCommand {
 
 /*
  * $Log: CancelTraceThreads.java,v $
- * Revision 1.2  2001/10/14 22:19:44  andyp
- * Sync to 2.2.8
+ * Revision 1.2  2003/01/15 05:56:26  paulk
+ * Add Petter Mahlen's changes.
  *
  * Revision 1.1  2001/03/24 05:48:40  paulk
  * Initial version.
