@@ -1,11 +1,11 @@
 ;;; jde-dbo.el -- JDEbug output functions
-;; $Revision: 1.39 $ $Date: 2003/09/27 05:34:36 $ 
+;; $Revision: 1.40 $ $Date: 2004/06/03 02:04:11 $ 
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1997, 1998, 1999, 2001, 2002 Paul Kinnucan.
+;; Copyright (C) 1997, 1998, 1999, 2001, 2002, 2004 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
 ;;; Code:
 
 (require 'eieio)
-(require 'tree-widget)
+(jde-require 'tree-widget)
 (require 'jde-widgets)
 
 (defclass jde-dbo-thread ()
@@ -565,6 +565,9 @@ The remaining elements are arguments to pass to the handler."
 
 (provide 'jde-dbo)
 ;; $Log: jde-dbo.el,v $
+;; Revision 1.40  2004/06/03 02:04:11  paulk
+;; jde-require tree-widget.
+;;
 ;; Revision 1.39  2003/09/27 05:34:36  ahyatt
 ;; Exceptions should break when the user selects to suspend the thread as
 ;; well (not just when the user selects to suspect all threads).
